@@ -1,7 +1,7 @@
 from datetime import datetime
 import csv
 import feedparser
-from post import Post
+from .post import Post
 
 
 class Home():
